"""
from django.db import models
from imger.fields import ImgerField


class Images(models.Model):
    image_path = ImgerField(upload_to='testing', width=400, height=200, mime='image/jpg', quality=80)

    def __unicode__(self):
        return self.image_path
"""



#!/usr/bin/env python
import sys
import os
import base64

if(__name__ == '__main__'):
    arglen = len(sys.argv)
    if arglen > 1:
        imgfile = open(sys.argv[1], 'rb').read()

        with open(sys.argv[1], "rb") as imageFile:
            payload = base64.b64encode(imageFile.read())

        file_name = os.path.splitext(sys.argv[1])
        fname = file_name[0]
        fext = file_name[1]

        b64imgfile = open(fname + fext + '.txt', 'w')
        for line in payload:
            b64imgfile.write(line)
        print fname
        print fext
        print('done')
    else:
        print('No img file specified!')



from django import forms
from django.utils.safestring import mark_safe


class ImgerWidget(forms.Widget):

    def __init__(self, attrs=None, *args, **kwargs):
        self.width = attrs['width']
        self.height = attrs['height']
        self.mime = attrs['mime']
        self.quality = attrs['quality']
        super(ImgerWidget, self).__init__(*args, **kwargs)

    class Media:
        js = (
            'imger/js/jquery-1.11.1.min.js',
            'imger/js/jquery.nouislider.js',
            'imger/js/form2js.js',
            'imger/js/canvas-to-blob.min.js',
            'imger/js/imger-compress.js',
            'imger/js/imger-ui.js',
            'imger/js/imger-init.js'
        )
        css = {
            'all': (
                'imger/css/bootstrap.css',
                'imger/css/bootstrap-theme.css',
                'imger/css/imger.css',
                'imger/css/jquery.nouislider.css'
            )
        }

    def render(self, name, value, attrs=None):
        w = self.width
        h = self.height
        t = self.mime
        q = self.quality

        print '%sX%s' % (w, h)

        return mark_safe("%s<br/><button data-width=\"%s\" data-height=\"%s\" data-mime=\"%s\" data-quality=\"%s\" type=\"button\" id=\"ImgerBrowseBTN\">Browse</button> <span id=\"ImgerBrowseLabel\">No image selected...</span><input id=\"ImgerDataURL\" name=\"%s\" type=\"hidden\" />" % (value, w, h, t, q, name))



from django.db import models
from django.core import exceptions
from imger.widgets import ImgerWidget
from django.conf import settings
import json
import re


class ImgerField(models.Field):
    description = "Handles imger images via dataurl"

    metaclass__ = models.SubfieldBase

    def __init__(
        self,
        upload_to='',
        width=300,
        height=200,
        mime='image/jpg',
        quality=100,
        *args,
        **kwargs
    ):
        self.upload_to = upload_to
        self.width = width
        self.height = height
        self.mime = mime
        self.quality = quality

        super(ImgerField, self).__init__(*args, **kwargs)

    def get_internal_type(self):
        return "Input"

    def db_type(self, connection):
        return 'char(200)'

    def to_python(self, value):
        if value is None:
            return None
        elif value == "":
            return ''
        elif isinstance(value, basestring):
            if(value.startswith('imgerDjango:')):
                arr = value.split(':imgerDjango:', 1)

                json_string = r'%s' % (arr[0][12:])
                dataurl = r'%s' % arr[1]

                formdata = json.loads(json_string)
                imgstr = re.search(r'base64,(.*)', dataurl).group(1)

                media_path = settings.MEDIA_ROOT
                path = r'%s/%s/%s' % (
                    media_path,
                    self.upload_to,
                    formdata['imagename']
                )

                output = open(path, 'wb')
                output.write(imgstr.decode('base64'))
                output.close()

                return r'%s/%s' % (self.upload_to, formdata['imagename'])
            else:
                return value
        else:
            raise exceptions.ValidationError(self.error_messages['invalid'])

    def get_prep_value(self, value):
        if not value:
            return ""
        elif isinstance(value, basestring):
            return value
        else:
            return value

    def value_to_string(self, obj):
        value = self._get_val_from_obj(obj)
        return self.get_prep_value(value)

    """def clean(self, value, model_instance):
        value = super(DictionaryField, self).clean(value, model_instance)
        return self.get_prep_value(value)"""

    def formfield(self, **kwargs):
        w = self.width
        h = self.height
        t = self.mime
        q = self.quality

        defaults = {
            'widget': ImgerWidget(
                attrs={
                    'width': w,
                    'height': h,
                    'mime': t,
                    'quality': q
                }
            )
        }
        defaults.update(kwargs)

        return super(ImgerField, self).formfield(**defaults)
